@@ -1,4 +1,5 @@
 NonRobust_lin <- function(g, y, e,iterations,sparse,debugging){
+
   p = dim(g)[2]
   
   x = cbind(1,g)
@@ -18,7 +19,6 @@ NonRobust_lin <- function(g, y, e,iterations,sparse,debugging){
   hatBeta = rep(1,p)
   hatInvTauSq = rep(1,p)
   hatLambdaSq=1
-  hatLambdaSqStar=1
   hatSigmaSq=1
   aStar=1 
   bStar=1
@@ -30,8 +30,9 @@ NonRobust_lin <- function(g, y, e,iterations,sparse,debugging){
   progress=0
   
   progress = ifelse(debugging, 10^(floor(log10(iterations))-1), 0)
-  if(sparse){fit=BLSS(g, y, w, iterations, hatAlpha, hatBeta, hatInvTauSq, invSigAlpha0, hatPi, hatLambdaSq, hatSigmaSq, aStar, bStar, alpha, gamma, sh1, sh0, progress)}
-  else{fit=BL(g, y, w, iterations, hatBeta, hatAlpha, hatInvTauSq, invSigAlpha0, hatLambdaSqStar, hatSigmaSq, aStar, bStar, alpha, gamma, progress)}
+  if(sparse){
+    fit=BLSS(g, y, w, iterations, hatAlpha, hatBeta, hatInvTauSq, invSigAlpha0, hatPi, hatLambdaSq, hatSigmaSq, aStar, bStar, alpha, gamma, sh1, sh0, progress)}
+  else{fit=BL(g, y, w, iterations, hatBeta, hatAlpha, hatInvTauSq, invSigAlpha0, hatLambdaSq, hatSigmaSq, aStar, bStar, alpha, gamma, progress)}
   out=list(fit=fit,iterations=iterations)
   return(out)
 }
